@@ -7,3 +7,7 @@ test_that("list_domains", {
 test_that("list_operations", {
   expect_error(svc$list_operations(), NA)
 })
+
+test_that("list_prices", {
+  expect_error(svc$list_prices(), NA)
+})
